@@ -4,7 +4,7 @@ use warnings;
 package App::Spec;
 use 5.010;
 
-our $VERSION = '0.001_002'; # TRIAL VERSION
+our $VERSION = '0.002_001'; # TRIAL VERSION
 
 use App::Spec::Command;
 use App::Spec::Option;
@@ -37,8 +37,10 @@ sub _read_default_spec {
 sub runner {
     my ($self) = @_;
     my $class = $self->class;
-    my $run = $class->new({
-        spec => $self
+    my $cmd = $class->new;
+    my $run = App::Spec::Run->new({
+        spec => $self,
+        cmd => $cmd,
     });
     return $run;
 }
@@ -511,6 +513,11 @@ Accessors for the things defined in the spec (file)
 
 L<App::AppSpec> - Utilities for App::Spec authors
 
+=head1 LICENSE
+
+This library is free software and may be distributed under the same terms
+as perl itself.
+
 =cut
 
 1;
